NativeChangeEvent

Struct NativeChangeEvent 

pub struct NativeChangeEvent { /* private fields */ }
Data associated with a change event.

Contains the new value and checked state for form controls.

Implementations

Source

impl NativeChangeEvent

Implementation of NativeChangeEvent construction.

pub fn new(value: String, checked: bool) -> Self

Creates a new change event with the given value and checked state.

Source

impl NativeChangeEvent

pub fn get_value(&self) -> &String

pub fn get_mut_value(&mut self) -> &mut String

pub fn set_value(&mut self, val: String) -> &mut Self

pub fn get_checked(&self) -> &bool

pub fn get_mut_checked(&mut self) -> &mut bool

pub fn set_checked(&mut self, val: bool) -> &mut Self