NativeInputEvent

Struct NativeInputEvent 

pub struct NativeInputEvent { /* private fields */ }
Data associated with an input event.

Contains the current value and the type of input change.

Implementations

Source

impl NativeInputEvent

Implementation of NativeInputEvent construction.

pub fn new(value: String, input_type: String) -> Self

Creates a new input event with the given value and input type.

Source

impl NativeInputEvent

pub fn get_value(&self) -> &String

pub fn get_mut_value(&mut self) -> &mut String

pub fn set_value(&mut self, val: String) -> &mut Self

pub fn get_input_type(&self) -> &String

pub fn get_mut_input_type(&mut self) -> &mut String

pub fn set_input_type(&mut self, val: String) -> &mut Self