pub struct HookContextCell(/* private fields */);Expand description
A Sync wrapper for single-threaded global HookContextInner access.
SAFETY: This type is only safe to use in single-threaded contexts
(e.g., WASM). It implements Sync to allow usage as a static
variable, but concurrent access from multiple threads would be
undefined behavior.