pub struct AudioContext { /* private fields */ }Expand description
The AudioContext class.
This API requires the following crate features to be activated: AudioContext
Implementations
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn destination(&self) -> AudioDestinationNode
pub fn destination(&self) -> AudioDestinationNode
Getter for the destination field of this object.
This API requires the following crate features to be activated: AudioContext, AudioDestinationNode
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn sample_rate(&self) -> f32
pub fn sample_rate(&self) -> f32
Getter for the sampleRate field of this object.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn current_time(&self) -> f64
pub fn current_time(&self) -> f64
Getter for the currentTime field of this object.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn listener(&self) -> AudioListener
pub fn listener(&self) -> AudioListener
Getter for the listener field of this object.
This API requires the following crate features to be activated: AudioContext, AudioListener
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn onstatechange(&self) -> Option<Function>
pub fn onstatechange(&self) -> Option<Function>
Getter for the onstatechange field of this object.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn set_onstatechange(&self, value: Option<&Function>)
pub fn set_onstatechange(&self, value: Option<&Function>)
Setter for the onstatechange field of this object.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn new() -> Result<AudioContext, JsValue>
pub fn new() -> Result<AudioContext, JsValue>
The new AudioContext(..) constructor, creating a new instance of AudioContext.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn create_buffer(
&self,
number_of_channels: u32,
length: u32,
sample_rate: f32,
) -> Result<AudioBuffer, JsValue>
pub fn create_buffer( &self, number_of_channels: u32, length: u32, sample_rate: f32, ) -> Result<AudioBuffer, JsValue>
The createBuffer() method.
This API requires the following crate features to be activated: AudioBuffer, AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn create_buffer_source(&self) -> Result<AudioBufferSourceNode, JsValue>
pub fn create_buffer_source(&self) -> Result<AudioBufferSourceNode, JsValue>
The createBufferSource() method.
This API requires the following crate features to be activated: AudioBufferSourceNode, AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn create_gain(&self) -> Result<GainNode, JsValue>
pub fn create_gain(&self) -> Result<GainNode, JsValue>
The createGain() method.
This API requires the following crate features to be activated: AudioContext, GainNode
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn decode_audio_data(
&self,
audio_data: &ArrayBuffer,
) -> Result<Promise, JsValue>
pub fn decode_audio_data( &self, audio_data: &ArrayBuffer, ) -> Result<Promise, JsValue>
The decodeAudioData() method.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn decode_audio_data_with_success_callback(
&self,
audio_data: &ArrayBuffer,
success_callback: &Function,
) -> Result<Promise, JsValue>
pub fn decode_audio_data_with_success_callback( &self, audio_data: &ArrayBuffer, success_callback: &Function, ) -> Result<Promise, JsValue>
The decodeAudioData() method.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Sourcepub fn decode_audio_data_with_success_callback_and_error_callback(
&self,
audio_data: &ArrayBuffer,
success_callback: &Function,
error_callback: &Function,
) -> Result<Promise, JsValue>
pub fn decode_audio_data_with_success_callback_and_error_callback( &self, audio_data: &ArrayBuffer, success_callback: &Function, error_callback: &Function, ) -> Result<Promise, JsValue>
The decodeAudioData() method.
This API requires the following crate features to be activated: AudioContext
Sourceimpl AudioContext
impl AudioContext
Methods from Deref<Target = BaseAudioContext>
Sourcepub fn destination(&self) -> AudioDestinationNode
pub fn destination(&self) -> AudioDestinationNode
Getter for the destination field of this object.
This API requires the following crate features to be activated: AudioDestinationNode, BaseAudioContext
Sourcepub fn sample_rate(&self) -> f32
pub fn sample_rate(&self) -> f32
Getter for the sampleRate field of this object.
This API requires the following crate features to be activated: BaseAudioContext
Sourcepub fn current_time(&self) -> f64
pub fn current_time(&self) -> f64
Getter for the currentTime field of this object.
This API requires the following crate features to be activated: BaseAudioContext
Sourcepub fn listener(&self) -> AudioListener
pub fn listener(&self) -> AudioListener
Getter for the listener field of this object.
This API requires the following crate features to be activated: AudioListener, BaseAudioContext
Sourcepub fn onstatechange(&self) -> Option<Function>
pub fn onstatechange(&self) -> Option<Function>
Getter for the onstatechange field of this object.
This API requires the following crate features to be activated: BaseAudioContext
Sourcepub fn set_onstatechange(&self, value: Option<&Function>)
pub fn set_onstatechange(&self, value: Option<&Function>)
Setter for the onstatechange field of this object.
This API requires the following crate features to be activated: BaseAudioContext
Sourcepub fn create_buffer(
&self,
number_of_channels: u32,
length: u32,
sample_rate: f32,
) -> Result<AudioBuffer, JsValue>
pub fn create_buffer( &self, number_of_channels: u32, length: u32, sample_rate: f32, ) -> Result<AudioBuffer, JsValue>
The createBuffer() method.
This API requires the following crate features to be activated: AudioBuffer, BaseAudioContext
Sourcepub fn create_buffer_source(&self) -> Result<AudioBufferSourceNode, JsValue>
pub fn create_buffer_source(&self) -> Result<AudioBufferSourceNode, JsValue>
The createBufferSource() method.
This API requires the following crate features to be activated: AudioBufferSourceNode, BaseAudioContext
Sourcepub fn create_gain(&self) -> Result<GainNode, JsValue>
pub fn create_gain(&self) -> Result<GainNode, JsValue>
The createGain() method.
This API requires the following crate features to be activated: BaseAudioContext, GainNode
Sourcepub fn decode_audio_data(
&self,
audio_data: &ArrayBuffer,
) -> Result<Promise, JsValue>
pub fn decode_audio_data( &self, audio_data: &ArrayBuffer, ) -> Result<Promise, JsValue>
The decodeAudioData() method.
This API requires the following crate features to be activated: BaseAudioContext
Sourcepub fn decode_audio_data_with_success_callback(
&self,
audio_data: &ArrayBuffer,
success_callback: &Function,
) -> Result<Promise, JsValue>
pub fn decode_audio_data_with_success_callback( &self, audio_data: &ArrayBuffer, success_callback: &Function, ) -> Result<Promise, JsValue>
The decodeAudioData() method.
This API requires the following crate features to be activated: BaseAudioContext
Sourcepub fn decode_audio_data_with_success_callback_and_error_callback(
&self,
audio_data: &ArrayBuffer,
success_callback: &Function,
error_callback: &Function,
) -> Result<Promise, JsValue>
pub fn decode_audio_data_with_success_callback_and_error_callback( &self, audio_data: &ArrayBuffer, success_callback: &Function, error_callback: &Function, ) -> Result<Promise, JsValue>
The decodeAudioData() method.
This API requires the following crate features to be activated: BaseAudioContext
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Sourcepub fn as_string(&self) -> Option<String>
pub fn as_string(&self) -> Option<String>
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Tests whether this JS value is undefined
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Tests whether this JS value is null or undefined
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Tests whether the type of this JS value is function.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Applies the binary in JS operator on the two JsValues.
Sourcepub fn loose_eq(&self, other: &JsValue) -> bool
pub fn loose_eq(&self, other: &JsValue) -> bool
Compare two JsValues for equality, using the == operator in JS.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Applies the binary >>> JS operator on the two JsValues.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Sourcepub fn pow(&self, rhs: &JsValue) -> JsValue
pub fn pow(&self, rhs: &JsValue) -> JsValue
Applies the binary ** JS operator on the two JsValues.
Sourcepub fn lt(&self, other: &JsValue) -> bool
pub fn lt(&self, other: &JsValue) -> bool
Applies the binary < JS operator on the two JsValues.
Sourcepub fn le(&self, other: &JsValue) -> bool
pub fn le(&self, other: &JsValue) -> bool
Applies the binary <= JS operator on the two JsValues.
Sourcepub fn ge(&self, other: &JsValue) -> bool
pub fn ge(&self, other: &JsValue) -> bool
Applies the binary >= JS operator on the two JsValues.
Sourcepub fn gt(&self, other: &JsValue) -> bool
pub fn gt(&self, other: &JsValue) -> bool
Applies the binary > JS operator on the two JsValues.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Applies the unary + JS operator on a JsValue. Can throw.