HookContextCell

Struct HookContextCell 

pub struct HookContextCell(/* private fields */);
A Sync wrapper for single-threaded global HookContextInner access.

SAFETY: This type is only safe to use in single-threaded contexts (e.g., WASM). It implements Sync to allow usage as a static variable, but concurrent access from multiple threads would be undefined behavior.

Implementations

Source

impl HookContextCell

Implementation of HookContextCell construction and access.

pub const fn get_inner(&self) -> &'static mut HookContextInner

Returns a mutable reference to the inner HookContextInner.

Returns
  • &'static mut HookContextInner - A mutable reference to the inner state.