pub struct SignalCell<T>{ /* private fields */ }Expand description
A Sync wrapper for single-threaded global Signal access.
SAFETY: This type is only safe to use in single-threaded contexts
(e.g., WASM). It implements Sync to allow usage as a static
variable, but concurrent access from multiple threads would be
undefined behavior.
Implementations
Sourceimpl<T> SignalCell<T>
Implementation of SignalCell construction and access.
impl<T> SignalCell<T>
Implementation of SignalCell construction and access.
Sourceimpl<T> SignalCell<T>
impl<T> SignalCell<T>
pub fn get_mut_inner(&mut self) -> &mut UnsafeCell<Option<Signal<T>>>
Sourceimpl<T> SignalCell<T>
impl<T> SignalCell<T>
pub fn new(inner: UnsafeCell<Option<Signal<T>>>) -> Self