Trait AsNode
Source pub trait AsNode {
// Required method
fn as_node(&self) -> Option<VirtualNode>;
}
Trait for types that can be converted into a VirtualNode for use in HTML expressions.
Implemented by primitive types, strings, and signals to allow seamless
embedding in HTML markup.
Converts this value into a VirtualNode, if possible.
SourceConverts a string slice into a text virtual node.
Converts this string slice into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts a bool into a text virtual node.
Converts this boolean into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts an f32 into a text virtual node.
Converts this float into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts an f64 into a text virtual node.
Converts this float into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts an i32 into a text virtual node.
Converts this integer into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts an i64 into a text virtual node.
Converts this integer into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts a usize into a text virtual node.
Converts this unsigned integer into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts a String into a text virtual node.
Converts this string into a text virtual node.
Returns
Option<VirtualNode> - Always Some with a text node.
SourceConverts a VirtualNode reference into an owned node.
SourceConverts a VirtualNode reference into an owned node.
SourceConverts a signal into a reactive text virtual node.