pub trait Debug {
// Required method
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
? formatting.
Debug should format the output in a programmer-facing, debugging context.
Generally speaking, you should just derive a Debug implementation.
When used with the alternate format specifier #?, the output is pretty-printed.
For more information on formatters, see the module-level documentation.
This trait can be used with #[derive] if all fields implement Debug. When
derived for structs, it will use the name of the struct, then {, then a
comma-separated list of each field’s name and Debug value, then }. For
enums, it will use the name of the variant and, if applicable, (, then the
Debug values of the fields, then ).
Stability
Derived Debug formats are not stable, and so may change with future Rust
versions. Additionally, Debug implementations of types provided by the
standard library (std, core, alloc, etc.) are not stable, and
may also change with future Rust versions.
Examples
Deriving an implementation:
#[derive(Debug)]
struct Point {
x: i32,
y: i32,
}
let origin = Point { x: 0, y: 0 };
assert_eq!(
format!("The origin is: {origin:?}"),
"The origin is: Point { x: 0, y: 0 }",
);Manually implementing:
use std::fmt;
struct Point {
x: i32,
y: i32,
}
impl fmt::Debug for Point {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
f.debug_struct("Point")
.field("x", &self.x)
.field("y", &self.y)
.finish()
}
}
let origin = Point { x: 0, y: 0 };
assert_eq!(
format!("The origin is: {origin:?}"),
"The origin is: Point { x: 0, y: 0 }",
);There are a number of helper methods on the Formatter struct to help you with manual
implementations, such as debug_struct.
Types that do not wish to use the standard suite of debug representations
provided by the Formatter trait (debug_struct, debug_tuple,
debug_list, debug_set, debug_map) can do something totally custom by
manually writing an arbitrary representation to the Formatter.
impl fmt::Debug for Point {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "Point [{} {}]", self.x, self.y)
}
}Debug implementations using either derive or the debug builder API
on Formatter support pretty-printing using the alternate flag: {:#?}.
Pretty-printing with #?:
#[derive(Debug)]
struct Point {
x: i32,
y: i32,
}
let origin = Point { x: 0, y: 0 };
let expected = "The origin is: Point {
x: 0,
y: 0,
}";
assert_eq!(format!("The origin is: {origin:#?}"), expected);Required Methods
1.0.0 · Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Formats the value using the given formatter.
Errors
This function should return Err if, and only if, the provided Formatter returns Err.
String formatting is considered an infallible operation; this function only
returns a Result because writing to the underlying stream might fail and it must
provide a way to propagate the fact that an error has occurred back up the stack.
Examples
use std::fmt;
struct Position {
longitude: f32,
latitude: f32,
}
impl fmt::Debug for Position {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
f.debug_tuple("")
.field(&self.longitude)
.field(&self.latitude)
.finish()
}
}
let position = Position { longitude: 1.987, latitude: 2.983 };
assert_eq!(format!("{position:?}"), "(1.987, 2.983)");
assert_eq!(format!("{position:#?}"), "(
1.987,
2.983,
)");Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl Debug for !
impl Debug for ()
impl Debug for Abi
impl Debug for AccessError
impl Debug for AddrParseError
impl Debug for AggregateError
impl Debug for core::mem::alignment::Alignment
impl Debug for euv_core::fmt::Alignment
impl Debug for AllocError
impl Debug for AncillaryError
impl Debug for AnimationEvent
impl Debug for App
impl Debug for Args
impl Debug for ArgsOs
impl Debug for Arguments<'_>
impl Debug for core::mem::type_info::Array
impl Debug for ArrayBuffer
impl Debug for ArrayBufferOptions
impl Debug for AsciiChar
impl Debug for Assume
impl Debug for Atomic<bool>
target_has_atomic_load_store=8 only.impl Debug for Atomic<i8>
impl Debug for Atomic<i16>
impl Debug for Atomic<i32>
impl Debug for Atomic<i64>
impl Debug for Atomic<isize>
impl Debug for Atomic<u8>
impl Debug for Atomic<u16>
impl Debug for Atomic<u32>
impl Debug for Atomic<u64>
impl Debug for Atomic<usize>
impl Debug for AtomicOrdering
impl Debug for AttributeEntry
impl Debug for AttributeValue
impl Debug for AudioBuffer
impl Debug for AudioBufferSourceNode
impl Debug for AudioContext
impl Debug for AudioDestinationNode
impl Debug for AudioListener
impl Debug for AudioNode
impl Debug for AudioParam
impl Debug for AudioScheduledSourceNode
impl Debug for Backtrace
impl Debug for BacktraceFrame
impl Debug for BacktraceStatus
impl Debug for BacktraceStyle
impl Debug for Barrier
impl Debug for BarrierWaitResult
impl Debug for BaseAudioContext
impl Debug for BeforeUnloadEvent
impl Debug for BigInt
impl Debug for BigInt64Array
impl Debug for BigUint64Array
impl Debug for Blob
impl Debug for Boolean
impl Debug for BorrowError
impl Debug for BorrowMutError
impl Debug for BorrowedFd<'_>
impl Debug for Builder
impl Debug for ByteStr
impl Debug for ByteString
impl Debug for CStr
Shows the underlying bytes as a normal string, with invalid UTF-8 presented as hex escape sequences.
impl Debug for CString
Delegates to the CStr implementation of fmt::Debug,
showing invalid UTF-8 as hex escapes.
impl Debug for CanvasGradient
impl Debug for CanvasRenderingContext2d
impl Debug for CharCase
impl Debug for CharTryFromError
impl Debug for CharacterData
impl Debug for Chars<'_>
impl Debug for Child
impl Debug for ChildStderr
impl Debug for ChildStdin
impl Debug for ChildStdout
impl Debug for Clipboard
impl Debug for ClipboardEvent
impl Debug for Collator
impl Debug for CollatorCaseFirst
impl Debug for CollatorOptions
impl Debug for CollatorSensitivity
impl Debug for CollatorUsage
impl Debug for Command
impl Debug for CommandResolvedEnvs
impl Debug for CompactDisplay
impl Debug for CompileError
impl Debug for Components<'_>
impl Debug for std::sync::nonpoison::condvar::Condvar
impl Debug for std::sync::poison::condvar::Condvar
impl Debug for Const
impl Debug for Context<'_>
impl Debug for CpuidResult
impl Debug for Css
impl Debug for CssStyleDeclaration
impl Debug for CurrencyDisplay
impl Debug for CurrencySign
impl Debug for DataTransfer
impl Debug for DataView
impl Debug for Date
impl Debug for DateTimeFormat
impl Debug for DateTimeFormatOptions
impl Debug for DateTimeFormatPart
impl Debug for DateTimeFormatPartType
impl Debug for DateTimeRangeFormatPart
impl Debug for DateTimeStyle
impl Debug for DayFormat
impl Debug for DayPeriodFormat
impl Debug for DebugAsHex
impl Debug for DecodeUtf16Error
impl Debug for DefaultHasher
impl Debug for DiffOp
impl Debug for Dir
impl Debug for DirBuilder
impl Debug for DirEntry
impl Debug for std::ffi::os_str::Display<'_>
impl Debug for std::path::Display<'_>
impl Debug for DisplayNames
impl Debug for DisplayNamesFallback
impl Debug for DisplayNamesLanguageDisplay
impl Debug for DisplayNamesOptions
impl Debug for DisplayNamesStyle
impl Debug for DisplayNamesType
impl Debug for Document
impl Debug for DocumentFragment
impl Debug for DomRect
impl Debug for DomRectReadOnly
impl Debug for DragEvent
impl Debug for alloc::string::Drain<'_>
impl Debug for core::time::Duration
impl Debug for js_sys::Intl::Duration
impl Debug for DurationFormat
impl Debug for DurationFormatOptions
impl Debug for DurationFormatPart
impl Debug for DurationFormatPartType
impl Debug for DurationFormatStyle
impl Debug for DurationTimeUnitStyle
impl Debug for DurationUnitDisplay
impl Debug for DurationUnitStyle
impl Debug for DynTrait
impl Debug for DynTraitPredicate
impl Debug for DynamicNode
impl Debug for Element
impl Debug for core::io::util::Empty
impl Debug for EncodeUtf16<'_>
impl Debug for EraFormat
impl Debug for core::io::error::Error
impl Debug for euv_core::fmt::Error
impl Debug for js_sys::Error
impl Debug for ErrorKind
impl Debug for ErrorOptions
impl Debug for core::char::EscapeDebug
impl Debug for core::ascii::EscapeDefault
impl Debug for core::char::EscapeDefault
impl Debug for core::char::EscapeUnicode
impl Debug for EvalError
impl Debug for Event
impl Debug for EventInit
impl Debug for EventSource
impl Debug for EventTarget
impl Debug for Exception
impl Debug for ExitCode
impl Debug for ExitStatus
impl Debug for ExitStatusError
impl Debug for FieldId
impl Debug for std::fs::File
impl Debug for web_sys::features::gen_File::File
impl Debug for FileList
impl Debug for FileReader
impl Debug for FileTimes
impl Debug for FileType
impl Debug for FinalizationRegistry
impl Debug for FireHandle
impl Debug for Float16Array
impl Debug for Float32Array
impl Debug for Float64Array
impl Debug for FnPtr
impl Debug for FocusEvent
impl Debug for FormattingOptions
impl Debug for FpCategory
impl Debug for FromBytesUntilNulError
impl Debug for FromBytesWithNulError
impl Debug for FromUtf8Error
impl Debug for FromUtf16Error
impl Debug for FromVecWithNulError
impl Debug for GainNode
impl Debug for Generic
impl Debug for GenericType
impl Debug for GetDisjointMutError
impl Debug for alloc::alloc::Global
impl Debug for js_sys::WebAssembly::Global
impl Debug for HashChangeEvent
impl Debug for History
impl Debug for HookContext
impl Debug for HookContextInner
impl Debug for HourCycle
impl Debug for HtmlButtonElement
impl Debug for HtmlCanvasElement
impl Debug for HtmlCollection
impl Debug for HtmlElement
impl Debug for HtmlFormElement
impl Debug for HtmlHeadElement
impl Debug for HtmlImageElement
impl Debug for HtmlInputElement
impl Debug for HtmlMediaElement
impl Debug for HtmlMetaElement
impl Debug for HtmlOptionElement
impl Debug for HtmlSelectElement
impl Debug for HtmlStyleElement
impl Debug for HtmlTextAreaElement
impl Debug for HtmlVideoElement
impl Debug for InputEvent
impl Debug for Instance
impl Debug for Instant
impl Debug for Int8Array
impl Debug for Int16Array
impl Debug for Int32Array
impl Debug for IntErrorKind
impl Debug for IntersectionObserver
impl Debug for IntersectionObserverEntry
impl Debug for IntersectionObserverInit
impl Debug for IntervalHandle
impl Debug for IntoChars
impl Debug for IntoIncoming
impl Debug for IntoStringError
impl Debug for IpAddr
impl Debug for Ipv4Addr
impl Debug for Ipv6Addr
impl Debug for Ipv6MulticastScope
impl Debug for std::path::Iter<'_>
impl Debug for JoinPathsError
impl Debug for JsError
impl Debug for JsString
impl Debug for JsValue
impl Debug for KeyboardEvent
impl Debug for Last
impl Debug for Layout
impl Debug for LayoutError
impl Debug for Lifetime
impl Debug for LinkError
impl Debug for ListFormat
impl Debug for ListFormatOptions
impl Debug for ListFormatPart
impl Debug for ListFormatPartType
impl Debug for ListFormatStyle
impl Debug for ListFormatType
impl Debug for LocalWaker
impl Debug for Locale
impl Debug for LocaleMatcher
impl Debug for LocaleMatcherOptions
impl Debug for Locality
impl Debug for web_sys::features::gen_Location::Location
impl Debug for core::panic::location::Location<'_>
impl Debug for MediaDevices
impl Debug for MediaQueryList
impl Debug for MediaRule
impl Debug for MediaStream
impl Debug for MediaStreamConstraints
impl Debug for MediaStreamTrack
impl Debug for Memory
impl Debug for MessageEvent
impl Debug for Metadata
impl Debug for Module
impl Debug for MonthFormat
impl Debug for MouseEvent
impl Debug for NativeEventHandler
impl Debug for Node
impl Debug for NodeList
impl Debug for NormalizeError
impl Debug for NulError
impl Debug for Null
impl Debug for Number
impl Debug for NumberFormat
impl Debug for NumberFormatNotation
impl Debug for NumberFormatOptions
impl Debug for NumberFormatPart
impl Debug for NumberFormatPartType
impl Debug for NumberFormatStyle
impl Debug for NumberRangeFormatPart
impl Debug for NumericFormat
impl Debug for std::sync::once::Once
impl Debug for OnceState
impl Debug for OpenOptions
impl Debug for core::cmp::Ordering
impl Debug for core::sync::atomic::Ordering
impl Debug for OsStr
impl Debug for OsString
impl Debug for Output
impl Debug for OwnedFd
impl Debug for PanicMessage<'_>
impl Debug for ParseBoolError
impl Debug for ParseCharError
impl Debug for ParseFloatError
impl Debug for ParseIntError
impl Debug for Path
impl Debug for PathBuf
impl Debug for Performance
impl Debug for Permissions
impl Debug for PhantomContravariantLifetime<'_>
impl Debug for PhantomCovariantLifetime<'_>
impl Debug for PhantomInvariantLifetime<'_>
impl Debug for PhantomPinned
impl Debug for PidFd
impl Debug for PipeReader
impl Debug for PipeWriter
impl Debug for PluralCategory
impl Debug for PluralRules
impl Debug for PluralRulesOptions
impl Debug for PluralRulesType
impl Debug for Pointer
impl Debug for Proxy
impl Debug for PseudoRule
impl Debug for RandomState
impl Debug for RangeError
impl Debug for RangeFull
impl Debug for RangeSource
impl Debug for RawHtml
impl Debug for RawWaker
impl Debug for RawWakerVTable
impl Debug for ReadDir
impl Debug for RecvError
impl Debug for std::sync::mpsc::RecvTimeoutError
impl Debug for Reference
impl Debug for ReferenceError
impl Debug for RegExp
impl Debug for RegExpMatchArray
impl Debug for RelativeTimeFormat
impl Debug for RelativeTimeFormatNumeric
impl Debug for RelativeTimeFormatOptions
impl Debug for RelativeTimeFormatPart
impl Debug for RelativeTimeFormatPartType
impl Debug for RelativeTimeFormatStyle
impl Debug for RelativeTimeFormatUnit
impl Debug for core::io::util::Repeat
impl Debug for ResolvedCollatorOptions
impl Debug for ResolvedDateTimeFormatOptions
impl Debug for ResolvedDisplayNamesOptions
impl Debug for ResolvedDurationFormatOptions
impl Debug for ResolvedListFormatOptions
impl Debug for ResolvedNumberFormatOptions
impl Debug for ResolvedPluralRulesOptions
impl Debug for ResolvedRelativeTimeFormatOptions
impl Debug for ResolvedSegmenterOptions
impl Debug for Response
impl Debug for RoundingMode
impl Debug for RoundingPriority
impl Debug for RuntimeError
impl Debug for Scope<'_, '_>
impl Debug for ScrollBehavior
impl Debug for ScrollIntoViewOptions
impl Debug for ScrollLogicalPosition
impl Debug for SearchStep
impl Debug for SeekFrom
impl Debug for SegmentData
impl Debug for Segmenter
impl Debug for SegmenterGranularity
impl Debug for SegmenterOptions
impl Debug for Segments
impl Debug for Shutdown
impl Debug for Sign
impl Debug for SignDisplay
impl Debug for SimdAlign
impl Debug for Sink
impl Debug for SipHasher
impl Debug for Slice
impl Debug for std::os::unix::net::addr::SocketAddr
impl Debug for core::net::socket_addr::SocketAddr
impl Debug for SocketAddrV4
impl Debug for SocketAddrV6
impl Debug for SplitPaths<'_>
impl Debug for Stderr
impl Debug for StderrLock<'_>
impl Debug for Stdin
impl Debug for StdinLock<'_>
impl Debug for Stdio
impl Debug for Stdout
impl Debug for StdoutLock<'_>
impl Debug for Storage
impl Debug for Str
impl Debug for String
impl Debug for StripPrefixError
impl Debug for SubmitEvent
impl Debug for SupportedValuesKey
impl Debug for Symbol
impl Debug for SyntaxError
impl Debug for System
impl Debug for SystemRng
impl Debug for SystemTime
impl Debug for SystemTimeError
impl Debug for Table
impl Debug for js_sys::WebAssembly::Tag
impl Debug for euv_core::Tag
impl Debug for TcpListener
impl Debug for TcpStream
impl Debug for Text
impl Debug for TextInfo
impl Debug for TextNode
impl Debug for Thread
impl Debug for ThreadId
impl Debug for TimeZoneNameFormat
impl Debug for ToCasefold
impl Debug for ToLowercase
impl Debug for ToTitlecase
impl Debug for ToUppercase
impl Debug for Touch
impl Debug for TouchEvent
impl Debug for TouchList
impl Debug for TrailingZeroDisplay
impl Debug for Trait
impl Debug for TransitionEvent
impl Debug for TryFromCharError
impl Debug for TryFromFloatSecsError
impl Debug for core::num::error::TryFromIntError
impl Debug for js_sys::TryFromIntError
impl Debug for TryFromSliceError
impl Debug for std::fs::TryLockError
impl Debug for std::sync::mpsc::TryRecvError
impl Debug for TryReserveError
impl Debug for TryReserveErrorKind
impl Debug for Type
impl Debug for TypeError
impl Debug for TypeId
impl Debug for TypeKind
impl Debug for UCred
impl Debug for UdpSocket
impl Debug for UiEvent
impl Debug for Uint8Array
impl Debug for Uint8ClampedArray
impl Debug for Uint16Array
impl Debug for Uint32Array
impl Debug for Undefined
impl Debug for UnitDisplay
impl Debug for UnixDatagram
impl Debug for UnixListener
impl Debug for UnixStream
impl Debug for UnorderedKeyError
impl Debug for UriError
impl Debug for UseGrouping
impl Debug for Utf8Chunks<'_>
impl Debug for Utf8Error
impl Debug for VaList<'_>
impl Debug for VarError
impl Debug for VariantId
impl Debug for Vars
impl Debug for VarsOs
impl Debug for VisualViewport
impl Debug for WaitTimeoutResult
impl Debug for Waker
impl Debug for WebGl2RenderingContext
impl Debug for WebGlBuffer
impl Debug for WebGlContextAttributes
impl Debug for WebGlProgram
impl Debug for WebGlShader
impl Debug for WebGlUniformLocation
impl Debug for WebSocket
impl Debug for WeekInfo
impl Debug for WeekdayFormat
impl Debug for WheelEvent
impl Debug for Window
impl Debug for WouldBlock
impl Debug for WriterPanicked
impl Debug for XdgDirsIter
impl Debug for YearFormat
impl Debug for __m128
impl Debug for __m256
impl Debug for __m512
impl Debug for __m128bh
impl Debug for __m128d
impl Debug for __m128h
impl Debug for __m128i
impl Debug for __m256bh
impl Debug for __m256d
impl Debug for __m256h
impl Debug for __m256i
impl Debug for __m512bh
impl Debug for __m512d
impl Debug for __m512h
impl Debug for __m512i
impl Debug for __tile1024i
impl Debug for bf16
impl Debug for bool
impl Debug for c_void
impl Debug for char
impl Debug for dyn Any
impl Debug for dyn Any + Send
impl Debug for dyn Any + Send + Sync
impl Debug for f16
impl Debug for f32
impl Debug for f64
impl Debug for f128
impl Debug for i8
impl Debug for i16
impl Debug for i32
impl Debug for i64
impl Debug for i128
impl Debug for isize
impl Debug for str
impl Debug for u8
impl Debug for u16
impl Debug for u32
impl Debug for u64
impl Debug for u128
impl Debug for usize
impl<'a, 'b, const N: usize> Debug for CharArrayRefSearcher<'a, 'b, N>
impl<'a, 'b> Debug for CharSliceSearcher<'a, 'b>
impl<'a, 'b> Debug for StrSearcher<'a, 'b>
impl<'a, A> Debug for core::option::Iter<'a, A>where
A: Debug + 'a,
impl<'a, A> Debug for core::option::IterMut<'a, A>where
A: Debug + 'a,
impl<'a, I, A> Debug for alloc::collections::vec_deque::splice::Splice<'a, I, A>
impl<'a, I, A> Debug for alloc::vec::splice::Splice<'a, I, A>
impl<'a, I> Debug for ByRefSized<'a, I>where
I: Debug,
impl<'a, P> Debug for MatchIndices<'a, P>
impl<'a, P> Debug for Matches<'a, P>
impl<'a, P> Debug for RMatchIndices<'a, P>
impl<'a, P> Debug for RMatches<'a, P>
impl<'a, P> Debug for core::str::iter::RSplit<'a, P>
impl<'a, P> Debug for core::str::iter::RSplitN<'a, P>
impl<'a, P> Debug for RSplitTerminator<'a, P>
impl<'a, P> Debug for core::str::iter::Split<'a, P>
impl<'a, P> Debug for core::str::iter::SplitInclusive<'a, P>
impl<'a, P> Debug for core::str::iter::SplitN<'a, P>
impl<'a, P> Debug for SplitTerminator<'a, P>
impl<'a, T, A> Debug for alloc::collections::binary_heap::Drain<'a, T, A>
impl<'a, T, A> Debug for DrainSorted<'a, T, A>
impl<'a, T, P> Debug for ChunkBy<'a, T, P>where
T: 'a + Debug,
impl<'a, T, P> Debug for ChunkByMut<'a, T, P>where
T: 'a + Debug,
impl<'a, T, const N: usize> Debug for ArrayWindows<'a, T, N>where
T: Debug + 'a,
impl<'a, T> Debug for ArrayIter<'a, T>
impl<'a, T> Debug for Chunks<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for ChunksExact<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for ChunksExactMut<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for ChunksMut<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for std::sync::mpmc::Iter<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for std::sync::mpsc::Iter<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for core::result::Iter<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for core::result::IterMut<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for RChunks<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for RChunksExact<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for RChunksExactMut<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for RChunksMut<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for alloc::collections::btree::set::Range<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for std::sync::mpmc::TryIter<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for std::sync::mpsc::TryIter<'a, T>where
T: Debug + 'a,
impl<'a, T> Debug for Windows<'a, T>where
T: Debug + 'a,
impl<'a, const N: usize> Debug for CharArraySearcher<'a, N>
impl<'a> Debug for Ancestors<'a>
impl<'a> Debug for core::ffi::c_str::Bytes<'a>
impl<'a> Debug for core::str::iter::Bytes<'a>
impl<'a> Debug for CharIndices<'a>
impl<'a> Debug for CharSearcher<'a>
impl<'a> Debug for CommandArgs<'a>
impl<'a> Debug for CommandEnvs<'a>
impl<'a> Debug for Component<'a>
impl<'a> Debug for ContextBuilder<'a>
impl<'a> Debug for EscapeAscii<'a>
impl<'a> Debug for core::str::iter::EscapeDebug<'a>
impl<'a> Debug for core::str::iter::EscapeDefault<'a>
impl<'a> Debug for core::str::iter::EscapeUnicode<'a>
impl<'a> Debug for std::net::tcp::Incoming<'a>
impl<'a> Debug for std::os::unix::net::listener::Incoming<'a>
impl<'a> Debug for IoSlice<'a>
impl<'a> Debug for IoSliceMut<'a>
impl<'a> Debug for core::str::iter::Lines<'a>
impl<'a> Debug for LinesAny<'a>
impl<'a> Debug for PanicHookInfo<'a>
impl<'a> Debug for PanicInfo<'a>
impl<'a> Debug for Prefix<'a>
impl<'a> Debug for PrefixComponent<'a>
impl<'a> Debug for Request<'a>
impl<'a> Debug for SocketAncillary<'a>
impl<'a> Debug for Source<'a>
impl<'a> Debug for core::slice::ascii::SplitAsciiWhitespace<'a>
impl<'a> Debug for core::str::iter::SplitAsciiWhitespace<'a>
impl<'a> Debug for SplitWhitespace<'a>
impl<'a> Debug for Utf8Chunk<'a>
impl<'a> Debug for Utf8Pattern<'a>
impl<'scope, T> Debug for ScopedJoinHandle<'scope, T>
impl<A, B> Debug for core::iter::adapters::chain::Chain<A, B>
impl<A, B> Debug for Zip<A, B>
impl<A> Debug for core::option::IntoIter<A>where
A: Debug,
impl<A> Debug for OptionFlatten<A>where
A: Debug,
impl<A> Debug for RangeFromIter<A>where
A: Debug,
impl<A> Debug for RangeInclusiveIter<A>where
A: Debug,
impl<A> Debug for RangeIter<A>where
A: Debug,
impl<A> Debug for core::iter::sources::repeat::Repeat<A>where
A: Debug,
impl<A> Debug for RepeatN<A>where
A: Debug,
impl<B, C> Debug for ControlFlow<B, C>
impl<B> Debug for Cow<'_, B>
impl<B> Debug for alloc::io::util::Lines<B>where
B: Debug,
impl<B> Debug for alloc::io::util::Split<B>where
B: Debug,
impl<Dyn> Debug for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Debug for Report<E>
impl<F> Debug for CharPredicateSearcher<'_, F>
impl<F> Debug for Fwhere
F: FnPtr,
impl<F> Debug for core::iter::sources::from_fn::FromFn<F>
impl<F> Debug for euv_core::fmt::FromFn<F>
impl<F> Debug for OnceWith<F>
impl<F> Debug for PollFn<F>
impl<F> Debug for RepeatWith<F>
impl<G> Debug for FromCoroutine<G>
impl<H> Debug for BuildHasherDefault<H>
impl<I, F, const N: usize> Debug for MapWindows<I, F, N>
impl<I, F> Debug for FilterMap<I, F>where
I: Debug,
impl<I, F> Debug for Inspect<I, F>where
I: Debug,
impl<I, F> Debug for core::iter::adapters::map::Map<I, F>where
I: Debug,
impl<I, G> Debug for IntersperseWith<I, G>
impl<I, P> Debug for Filter<I, P>where
I: Debug,
impl<I, P> Debug for MapWhile<I, P>where
I: Debug,
impl<I, P> Debug for SkipWhile<I, P>where
I: Debug,
impl<I, P> Debug for TakeWhile<I, P>where
I: Debug,
impl<I, St, F> Debug for Scan<I, St, F>
impl<I, U, F> Debug for FlatMap<I, U, F>
impl<I, U> Debug for Flatten<I>
impl<I, const N: usize> Debug for ArrayChunks<I, N>
impl<I> Debug for Cloned<I>where
I: Debug,
impl<I> Debug for Copied<I>where
I: Debug,
impl<I> Debug for Cycle<I>where
I: Debug,
impl<I> Debug for DecodeUtf16<I>
impl<I> Debug for Enumerate<I>where
I: Debug,
impl<I> Debug for FromIter<I>where
I: Debug,
impl<I> Debug for Fuse<I>where
I: Debug,
impl<I> Debug for Intersperse<I>
impl<I> Debug for Peekable<I>
impl<I> Debug for Skip<I>where
I: Debug,
impl<I> Debug for StepBy<I>where
I: Debug,
impl<I> Debug for core::iter::adapters::take::Take<I>where
I: Debug,
impl<Idx> Debug for Clamp<Idx>where
Idx: Debug,
impl<Idx> Debug for core::ops::range::Range<Idx>where
Idx: Debug,
impl<Idx> Debug for core::range::Range<Idx>where
Idx: Debug,
impl<Idx> Debug for core::ops::range::RangeFrom<Idx>where
Idx: Debug,
impl<Idx> Debug for core::range::RangeFrom<Idx>where
Idx: Debug,
impl<Idx> Debug for core::ops::range::RangeInclusive<Idx>where
Idx: Debug,
impl<Idx> Debug for core::range::RangeInclusive<Idx>where
Idx: Debug,
impl<Idx> Debug for RangeTo<Idx>where
Idx: Debug,
impl<Idx> Debug for core::ops::range::RangeToInclusive<Idx>where
Idx: Debug,
impl<Idx> Debug for core::range::RangeToInclusive<Idx>where
Idx: Debug,
impl<K, A> Debug for alloc::collections::btree::set::CursorMut<'_, K, A>where
K: Debug,
impl<K, A> Debug for alloc::collections::btree::set::CursorMutKey<'_, K, A>where
K: Debug,
impl<K, A> Debug for std::collections::hash::set::Drain<'_, K, A>
impl<K, A> Debug for std::collections::hash::set::IntoIter<K, A>
impl<K, F, A> Debug for std::collections::hash::set::ExtractIf<'_, K, F, A>
impl<K, V, A> Debug for BTreeMap<K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::CursorMut<'_, K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::CursorMutKey<'_, K, V, A>
impl<K, V, A> Debug for std::collections::hash::map::Drain<'_, K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::entry::Entry<'_, K, V, A>
impl<K, V, A> Debug for std::collections::hash::map::IntoIter<K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::IntoIter<K, V, A>
impl<K, V, A> Debug for std::collections::hash::map::IntoKeys<K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::IntoKeys<K, V, A>where
K: Debug,
A: AllocatorClone,
impl<K, V, A> Debug for std::collections::hash::map::IntoValues<K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::IntoValues<K, V, A>where
V: Debug,
A: AllocatorClone,
impl<K, V, A> Debug for alloc::collections::btree::map::entry::OccupiedEntry<'_, K, V, A>
impl<K, V, A> Debug for std::collections::hash::map::OccupiedEntry<'_, K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::entry::OccupiedError<'_, K, V, A>
impl<K, V, A> Debug for std::collections::hash::map::OccupiedError<'_, K, V, A>
impl<K, V, A> Debug for alloc::collections::btree::map::entry::VacantEntry<'_, K, V, A>
impl<K, V, A> Debug for std::collections::hash::map::VacantEntry<'_, K, V, A>
impl<K, V, F, A> Debug for std::collections::hash::map::ExtractIf<'_, K, V, F, A>
impl<K, V, R, F, A> Debug for alloc::collections::btree::map::ExtractIf<'_, K, V, R, F, A>
impl<K, V, S, A> Debug for HashMap<K, V, S, A>
impl<K, V: Debug> Debug for LruCache<K, V>
impl<K, V> Debug for alloc::collections::btree::map::Cursor<'_, K, V>
impl<K, V> Debug for std::collections::hash::map::Entry<'_, K, V>
impl<K, V> Debug for std::collections::hash::map::Iter<'_, K, V>
impl<K, V> Debug for alloc::collections::btree::map::Iter<'_, K, V>
impl<K, V> Debug for std::collections::hash::map::IterMut<'_, K, V>
impl<K, V> Debug for alloc::collections::btree::map::IterMut<'_, K, V>
impl<K, V> Debug for std::collections::hash::map::Keys<'_, K, V>where
K: Debug,
impl<K, V> Debug for alloc::collections::btree::map::Keys<'_, K, V>where
K: Debug,
impl<K, V> Debug for js_sys::Map<K, V>
impl<K, V> Debug for alloc::collections::btree::map::Range<'_, K, V>
impl<K, V> Debug for RangeMut<'_, K, V>
impl<K, V> Debug for std::collections::hash::map::Values<'_, K, V>where
V: Debug,
impl<K, V> Debug for alloc::collections::btree::map::Values<'_, K, V>where
V: Debug,
impl<K, V> Debug for std::collections::hash::map::ValuesMut<'_, K, V>where
V: Debug,
impl<K, V> Debug for alloc::collections::btree::map::ValuesMut<'_, K, V>where
V: Debug,
impl<K, V> Debug for WeakMap<K, V>
impl<K> Debug for alloc::collections::btree::set::Cursor<'_, K>where
K: Debug,
impl<K> Debug for std::collections::hash::set::Iter<'_, K>where
K: Debug,
impl<P> Debug for MaybeDangling<P>
impl<Ptr> Debug for Pin<Ptr>where
Ptr: Debug,
impl<R> Debug for BufReader<R>
impl<R> Debug for alloc::io::util::Bytes<R>where
R: Debug,
impl<T, A> Debug for Arc<T, A>
impl<T, A> Debug for BTreeSet<T, A>where
T: Debug,
A: AllocatorClone,
impl<T, A> Debug for BinaryHeap<T, A>
impl<T, A> Debug for Box<T, A>
impl<T, A> Debug for alloc::collections::linked_list::Cursor<'_, T, A>
impl<T, A> Debug for alloc::collections::linked_list::CursorMut<'_, T, A>
impl<T, A> Debug for alloc::collections::btree::set::Difference<'_, T, A>where
T: Debug,
A: AllocatorClone,
impl<T, A> Debug for alloc::collections::vec_deque::drain::Drain<'_, T, A>
impl<T, A> Debug for alloc::vec::drain::Drain<'_, T, A>
impl<T, A> Debug for alloc::collections::btree::set::entry::Entry<'_, T, A>
impl<T, A> Debug for alloc::collections::btree::set::Intersection<'_, T, A>where
T: Debug,
A: AllocatorClone,
impl<T, A> Debug for alloc::collections::binary_heap::IntoIter<T, A>
impl<T, A> Debug for alloc::collections::linked_list::IntoIter<T, A>
impl<T, A> Debug for alloc::collections::vec_deque::into_iter::IntoIter<T, A>
impl<T, A> Debug for alloc::vec::into_iter::IntoIter<T, A>
impl<T, A> Debug for alloc::collections::btree::set::IntoIter<T, A>
impl<T, A> Debug for IntoIterSorted<T, A>
impl<T, A> Debug for LinkedList<T, A>
impl<T, A> Debug for alloc::collections::btree::set::entry::OccupiedEntry<'_, T, A>
impl<T, A> Debug for alloc::vec::peek_mut::PeekMut<'_, T, A>
impl<T, A> Debug for alloc::collections::binary_heap::PeekMut<'_, T, A>
impl<T, A> Debug for Rc<T, A>
impl<T, A> Debug for UniqueArc<T, A>
impl<T, A> Debug for UniqueRc<T, A>
impl<T, A> Debug for alloc::collections::btree::set::entry::VacantEntry<'_, T, A>
impl<T, A> Debug for Vec<T, A>
impl<T, A> Debug for VecDeque<T, A>
impl<T, A> Debug for alloc::rc::Weak<T, A>
impl<T, A> Debug for alloc::sync::Weak<T, A>
impl<T, E> Debug for Result<T, E>
impl<T, F, A> Debug for alloc::collections::linked_list::ExtractIf<'_, T, F, A>
impl<T, F, A> Debug for alloc::collections::vec_deque::extract_if::ExtractIf<'_, T, F, A>
impl<T, F, A> Debug for alloc::vec::extract_if::ExtractIf<'_, T, F, A>
impl<T, F> Debug for DropGuard<T, F>
impl<T, F> Debug for Lazy<T, F>where
T: Debug,
impl<T, F> Debug for LazyCell<T, F>where
T: Debug,
impl<T, F> Debug for LazyLock<T, F>where
T: Debug,
impl<T, F> Debug for Successors<T, F>where
T: Debug,
impl<T, P> Debug for core::slice::iter::RSplit<'_, T, P>
impl<T, P> Debug for RSplitMut<'_, T, P>
impl<T, P> Debug for core::slice::iter::RSplitN<'_, T, P>
impl<T, P> Debug for RSplitNMut<'_, T, P>
impl<T, P> Debug for core::slice::iter::Split<'_, T, P>
impl<T, P> Debug for core::slice::iter::SplitInclusive<'_, T, P>
impl<T, P> Debug for SplitInclusiveMut<'_, T, P>
impl<T, P> Debug for SplitMut<'_, T, P>
impl<T, P> Debug for core::slice::iter::SplitN<'_, T, P>
impl<T, P> Debug for SplitNMut<'_, T, P>
impl<T, R, F, A> Debug for alloc::collections::btree::set::ExtractIf<'_, T, R, F, A>where
T: Debug,
A: AllocatorClone,
impl<T, S, A> Debug for std::collections::hash::set::Difference<'_, T, S, A>
impl<T, S, A> Debug for std::collections::hash::set::Entry<'_, T, S, A>
impl<T, S, A> Debug for HashSet<T, S, A>
impl<T, S, A> Debug for std::collections::hash::set::Intersection<'_, T, S, A>
impl<T, S, A> Debug for std::collections::hash::set::OccupiedEntry<'_, T, S, A>
impl<T, S, A> Debug for std::collections::hash::set::SymmetricDifference<'_, T, S, A>
impl<T, S, A> Debug for std::collections::hash::set::Union<'_, T, S, A>
impl<T, S, A> Debug for std::collections::hash::set::VacantEntry<'_, T, S, A>
impl<T, U> Debug for core::io::util::Chain<T, U>
impl<T, const N: usize, A> Debug for BoxedArrayIntoIter<T, N, A>
impl<T, const N: usize> Debug for core::array::iter::IntoIter<T, N>where
T: Debug,
impl<T, const N: usize> Debug for Mask<T, N>where
T: MaskElement + Debug,
impl<T, const N: usize> Debug for Simd<T, N>where
T: SimdElement + Debug,
impl<T, const N: usize> Debug for [T; N]where
T: Debug,
impl<T, const VARIANT: u32, const FIELD: u32> Debug for FieldRepresentingType<T, VARIANT, FIELD>where
T: ?Sized,
impl<T: ?Sized> Debug for NodeRef<T>
impl<T: Debug> Debug for AttrValueAdapter<T>
impl<T: Debug> Debug for CallbackNamedAdapter<T>
impl<T: Debug> Debug for EventAdapter<T>
impl<T: Debug> Debug for EventNamedAdapter<T>
impl<T: Debug> Debug for InnerHtmlAdapter<T>
impl<T: Debug> Debug for VirtualNode<T>
Debug formatting for VirtualNode<T>.
Skips Dynamic inner details and props for brevity.
impl<T> Debug for &T
impl<T> Debug for &mut T
impl<T> Debug for (T₁, T₂, …, Tₙ)where
T: Debug,
This trait is implemented for tuples up to twelve items long.
impl<T> Debug for *const Twhere
T: ?Sized,
impl<T> Debug for *mut Twhere
T: ?Sized,
impl<T> Debug for js_sys::Array<T>where
T: Debug,
impl<T> Debug for ArrayIntoIter<T>
impl<T> Debug for ArrayTuple<T>
impl<T> Debug for AssertUnwindSafe<T>where
T: Debug,
impl<T> Debug for AsyncGenerator<T>where
T: Debug,
impl<T> Debug for AsyncIterator<T>where
T: Debug,
impl<T> Debug for Atomic<*mut T>
target_has_atomic_load_store=ptr only.