pub trait IntoEventAttribute {
// Required method
fn into_event_attribute(self) -> AttributeValue;
}Expand description
Trait for types that can be converted into an event attribute value.
Allows event handlers and optional handlers to be used as attribute values.
Required Methods
Sourcefn into_event_attribute(self) -> AttributeValue
fn into_event_attribute(self) -> AttributeValue
Converts this value into an AttributeValue, or an empty text if None.
Implementations on Foreign Types
Sourceimpl IntoEventAttribute for Option<NativeEventHandler>
Converts an optional event handler into an attribute value.
impl IntoEventAttribute for Option<NativeEventHandler>
Converts an optional event handler into an attribute value.
fn into_event_attribute(self) -> AttributeValue
Implementors
impl IntoEventAttribute for NativeEventHandler
Converts an owned event handler into an attribute value.