NativeTouchEvent

Struct NativeTouchEvent 

pub struct NativeTouchEvent { /* private fields */ }
Data associated with a touch event.

Captures the number of touch points and the first touch coordinates.

Implementations

Source

impl NativeTouchEvent

Implementation of NativeTouchEvent construction.

pub fn new(touches_count: u32, client_x: i32, client_y: i32) -> Self

Creates a new touch event with the given parameters.

Source

impl NativeTouchEvent

pub fn get_touches_count(&self) -> &u32

pub fn get_mut_touches_count(&mut self) -> &mut u32

pub fn set_touches_count(&mut self, val: u32) -> &mut Self

pub fn get_client_x(&self) -> &i32

pub fn get_mut_client_x(&mut self) -> &mut i32

pub fn set_client_x(&mut self, val: i32) -> &mut Self

pub fn get_client_y(&self) -> &i32

pub fn get_mut_client_y(&mut self) -> &mut i32

pub fn set_client_y(&mut self, val: i32) -> &mut Self