pub struct Renderer { /* private fields */ }Expand description
Manages the rendering of virtual DOM nodes to the real DOM.
Maintains a mapping between virtual nodes and real DOM elements, and handles creation, diffing, and patching of the DOM tree.
Implementations
Sourceimpl Renderer
Implementation of the virtual DOM renderer.
impl Renderer
Implementation of the virtual DOM renderer.
Sourcepub fn render(&mut self, vnode: VirtualNode)
pub fn render(&mut self, vnode: VirtualNode)
Renders the given virtual DOM tree into the real DOM.
Sourceimpl Renderer
impl Renderer
pub fn get_node_map(&self) -> &HashMap<usize, Element>
pub fn get_mut_node_map(&mut self) -> &mut HashMap<usize, Element>
pub fn set_node_map(&mut self, val: HashMap<usize, Element>) -> &mut Self
pub fn get_root(&self) -> &Element
pub fn get_mut_root(&mut self) -> &mut Element
pub fn set_root(&mut self, val: Element) -> &mut Self
pub fn get_current_tree(&self) -> VirtualNode
pub fn try_get_current_tree(&self) -> &Option<VirtualNode>
pub fn get_mut_current_tree(&mut self) -> &mut Option<VirtualNode>
pub fn set_current_tree(&mut self, val: Option<VirtualNode>) -> &mut Self
pub fn get_next_id(&self) -> &Rc<RefCell<usize>>
pub fn get_mut_next_id(&mut self) -> &mut Rc<RefCell<usize>>
pub fn set_next_id(&mut self, val: Rc<RefCell<usize>>) -> &mut Self