pub struct HookContextCell(/* private fields */);Expand description
A Sync wrapper for single-threaded global HookContextInner access.
SAFETY: This type is only safe to use in single-threaded contexts
(e.g., WASM). It implements Sync to allow usage as a static
variable, but concurrent access from multiple threads would be
undefined behavior.
Implementations
Sourceimpl HookContextCell
Implementation of HookContextCell construction and access.
impl HookContextCell
Implementation of HookContextCell construction and access.
Sourcepub const fn get_inner(&self) -> &'static mut HookContextInner
pub const fn get_inner(&self) -> &'static mut HookContextInner
Returns a mutable reference to the inner HookContextInner.
Returns
&'static mut HookContextInner- A mutable reference to the inner state.