IntoEventAttribute

Trait IntoEventAttribute 

pub trait IntoEventAttribute {
    // Required method
    fn into_event_attribute(self) -> AttributeValue;
}
Trait for types that can be converted into an event attribute value.

Allows event handlers and optional handlers to be used as attribute values.

Required Methods

fn into_event_attribute(self) -> AttributeValue

Converts this value into an AttributeValue, or an empty text if None.

Implementations on Foreign Types

Source

impl IntoEventAttribute for Option<NativeEventHandler>

Converts an optional event handler into an attribute value.

Implementors

Source

impl IntoEventAttribute for NativeEventHandler

Converts an owned event handler into an attribute value.